@@ -39,7 +39,7 @@
 #include "Database.h"
 
 #include "Data.h"
-#include <iostream>
+
 class ValueDialog : public Lum::Dialog
 {
 private:
@@ -131,15 +131,15 @@ bool GetStringValue(Lum::OS::Window* parent,
 class LinkNameTypeDialog : public Lum::Dialog
 {
 private:
-  Lum::Model::ListTableRef model;
-  Lum::Model::ActionRef    okAction;
-  Lum::Model::StringRef    nameModel;
-  Lum::Model::StringRef    typeModel;
-  bool                     success;
+  Lum::Model::StringTableRef model;
+  Lum::Model::ActionRef      okAction;
+  Lum::Model::StringRef      nameModel;
+  Lum::Model::StringRef      typeModel;
+  bool                       success;
 
 public:
   LinkNameTypeDialog()
-  : model(new Lum::Model::ListTable()),
+  : model(new Lum::Model::StringTable()),
     okAction(new Lum::Model::Action),
     nameModel(new Lum::Model::String),
     typeModel(new Lum::Model::String),
@@ -156,15 +156,11 @@ public:
 
     type=Base::Type::typeList.begin();
     while (type!=Base::Type::typeList.end()) {
-      Lum::Model::ListTable::StdEntry *entry;
-
       if (type==Base::Type::typeList.begin()) {
         typeModel->Set((*type)->GetName());
       }
 
-      entry=new Lum::Model::ListTable::StdEntry(model);
-      entry->SetString(1,(*type)->GetName());
-      model->Append(entry);
+      model->Append((*type)->GetName());
 
       ++type;
     }
@@ -192,9 +188,7 @@ public:
 
     combo=new Lum::TextCombo();
     combo->SetFlex(true,false);
-    if (!combo->SetModel(typeModel)) {
-      std::cout << "Cannot set model!" << std::endl;
-    }
+    combo->SetModel(typeModel);
     combo->SetTableModel(model);
     label->AddLabel(new Lum::Text(L"Type:"),combo);
 
@@ -237,7 +231,6 @@ public:
   {
     name=nameModel->Get();
     type=typeModel->Get();
-    std::cout << Lum::Base::WStringToString(name) << " " << Lum::Base::WStringToString(type) << std::endl;
   }
 };
 
@@ -267,50 +260,61 @@ bool GetLinkNameType(Lum::OS::Window* parent,
   }
 }
 
-class DataEntry : public Lum::Model::ListTable::Entry
+class DataEntry
 {
 public:
   Base::DataPtr data;
 
 public:
-  DataEntry(Lum::Model::ListTable* table,Base::DataPtr data)
-  : Lum::Model::ListTable::Entry(table),data(data)
+  DataEntry(Base::DataPtr data)
+  : data(data)
   {
     // no code
   }
+};
 
-  std::wstring GetString(size_t column) const
+typedef Lum::Model::StdTable<DataEntry>      DataEntryModel;
+typedef Lum::Base::Reference<DataEntryModel> DataEntryModelRef;
+
+class DataEntryDataProvider : public DataEntryModel::DataProvider
+{
+public:
+  std::wstring GetString(const DataEntryModel::Iterator& iter, size_t column) const
   {
-    return data->GetDisplayText();
-  }
-
-  bool IsGreater(const Entry* other, size_t column) const
-  {
-    const DataEntry *tmp=dynamic_cast<const DataEntry*>(other);
-
-    return data->IsGreater(tmp->data);
+    return iter->data->GetDisplayText();
   }
 };
 
+class DataEntryComparator : public DataEntryModel::Comparator
+{
+public:
+  bool operator()(const DataEntryModel::ElementType& a,
+                  const DataEntryModel::ElementType& b,
+                  size_t column, bool down) const
+  {
+    return !a.data->IsGreater(b.data);
+  }
+};
 
 class DataLinkDialog : public Lum::Dialog
 {
 private:
-  Lum::Model::ListTableRef           model;
+  Lum::Model::StringTableRef         model;
   Lum::Model::ActionRef              okAction;
   Lum::Model::StringRef              nameModel;
   Lum::Model::SizeTRef               typeModel;
-  Lum::Model::ListTableRef           dataModel;
+  DataEntryModelRef                  dataModel;
   Lum::Model::SingleLineSelectionRef selectionModel;
   bool                               success;
 
 public:
   DataLinkDialog()
-  : model(new Lum::Model::ListTable()),
+  : model(new Lum::Model::StringTable()),
     okAction(new Lum::Model::Action),
     nameModel(new Lum::Model::String),
     typeModel(new Lum::Model::SizeT),
-    dataModel(new Lum::Model::ListTable()),
+    dataModel(new DataEntryModel(new DataEntryDataProvider(),
+                                 new DataEntryComparator())),
     selectionModel(new Lum::Model::SingleLineSelection()),
     success(false)
   {
@@ -325,11 +329,7 @@ public:
     std::list<Base::TypePtr>::const_iterator type;
     type=Base::Type::typeList.begin();
     while (type!=Base::Type::typeList.end()) {
-      Lum::Model::ListTable::StdEntry *entry;
-
-      entry=new Lum::Model::ListTable::StdEntry(model);
-      entry->SetString(1,(*type)->GetName());
-      model->Append(entry);
+      model->Append((*type)->GetName());
 
       ++type;
     }
@@ -415,7 +415,7 @@ public:
           iter=database->database.begin();
           while (iter!=database->database.end()) {
             if ((*iter)->GetType()==type) {
-              dataModel->Append(new DataEntry(dataModel,(*iter)));
+              dataModel->Append(DataEntry((*iter)));
             }
             ++iter;
           }
@@ -437,7 +437,7 @@ public:
   void GetResult(std::wstring& name, ::Base::DataPtr& data) const
   {
     name=nameModel->Get();
-    data=dynamic_cast<DataEntry*>(dataModel->GetEntry(selectionModel->GetLine()))->data;
+    data=dataModel->GetEntry(selectionModel->GetLine()).data;
   }
 };
 
