@@ -49,8 +49,7 @@ namespace Views {
     Lum::Combo                      *combo;
     Lum::Label                      *label;
     Lum::DateSelect                 *select;
-    Lum::Model::ListTableRef        model;
-    Lum::Model::ListTable::StdEntry *entry;
+    Lum::Model::StringTableRef       model;
     Lum::TimeSelect                 *timeSelect;
     Lum::Panel                      *row;
 
@@ -75,27 +74,13 @@ namespace Views {
 
     label=Lum::Label::Create(true,false);
 
-    model=new Lum::Model::ListTable();
+    model=new Lum::Model::StringTable();
 
-    entry=new Lum::Model::ListTable::StdEntry(model);
-    entry->SetString(1,L"No repetition");
-    model->Append(entry);
-
-    entry=new Lum::Model::ListTable::StdEntry(model);
-    entry->SetString(1,L"Daily");
-    model->Append(entry);
-
-    entry=new Lum::Model::ListTable::StdEntry(model);
-    entry->SetString(1,L"Weekly");
-    model->Append(entry);
-
-    entry=new Lum::Model::ListTable::StdEntry(model);
-    entry->SetString(1,L"Monthly");
-    model->Append(entry);
-
-    entry=new Lum::Model::ListTable::StdEntry(model);
-    entry->SetString(1,L"Yearly");
-    model->Append(entry);
+    model->Append(L"No repetition");
+    model->Append(L"Daily");
+    model->Append(L"Weekly");
+    model->Append(L"Monthly");
+    model->Append(L"Yearly");
 
     combo=new Lum::IndexCombo();
     combo->SetFlex(true,false);
